use diesel;
use diesel::prelude::*;
use diesel::sqlite::SqliteConnection;

use crate::models::Image;
use dotenv::dotenv;
use std::env;

pub fn establish_connection() -> SqliteConnection {
    dotenv().ok();

    let database_url = env::var("DATABASE_URL").expect("DATABASE_URL must be set");
    SqliteConnection::establish(&database_url)
        .expect(&format!("Error connecting to {}", database_url))
}

pub fn load_images() -> Vec<Image> {
    use crate::schema::images::dsl::*;

    let connection = establish_connection();
    images
        .filter(published.eq(false))
        .limit(50)
        .load::<Image>(&connection)
        .expect("Error loading images")
}
